(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    134913,       4276]
NotebookOptionsPosition[    122576,       3926]
NotebookOutlinePosition[    122935,       3942]
CellTagsIndexPosition[    122892,       3939]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Beast Study: data i/o, functions, and graphics", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[
 RowBox[{"DateString", "[", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Dir", "=", " ", "\"\<V2.1\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SaveNames", "=", "\"\<V2_1_\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "SetDirectory", "[", "\"\</Users/ccarter/People/Neri/Chair/SaveData\>\"", 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CreateDirectory", "[", 
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir"}], 
   "]"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "137", "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ComputationalGeometry`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Helper Functions", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChopMaxMin", "[", 
   RowBox[{"vals_", ",", " ", "min_", ",", " ", "max_"}], "]"}], " ", ":=", 
  " ", 
  RowBox[{"vals", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a_", "/;", 
       RowBox[{"a", "<", "min"}]}], "\[Rule]", "min"}], ",", 
     RowBox[{
      RowBox[{"b_", "/;", 
       RowBox[{"b", ">", "max"}]}], "\[Rule]", "max"}]}], "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell["Splines", "Subsection"],

Cell[CellGroupData[{

Cell["division by zero is defined a zero ", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BSDivZero", "[", 
   RowBox[{"num_", ",", " ", "den_"}], "]"}], " ", ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"PossibleZeroQ", "[", "den", "]"}], ",", "0", ",", 
    RowBox[{"num", "/", "den"}]}], "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
the zero order basis functions (here look for the zero case first, as it is \
more frequent).\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSBF", "[", 
    RowBox[{"i_Integer", ",", "0", ",", " ", "uvec_", ",", "u_"}], "]"}], " ",
    ":=", " ", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ishift", " ", "=", " ", 
       RowBox[{"i", "+", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{
           RowBox[{"u", " ", "<", " ", 
            RowBox[{"uvec", "[", 
             RowBox[{"[", "ishift", "]"}], "]"}]}], " ", "||", " ", 
           RowBox[{"u", "\[GreaterEqual]", " ", 
            RowBox[{"uvec", "[", 
             RowBox[{"[", 
              RowBox[{"ishift", "+", "1"}], "]"}], "]"}]}]}]}], "}"}], "}"}], 
       ",", "1"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
Recursive (deBoor ) definition for basis function (not most efficient).\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BSBF", "[", 
   RowBox[{"i_Integer", ",", " ", 
    RowBox[{"degree_Integer", "/;", 
     RowBox[{"degree", ">", " ", "0"}]}], ",", "uvec_", " ", ",", "u_"}], 
   "]"}], " ", ":=", "\[IndentingNewLine]", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"knotlength", "=", 
       RowBox[{"Length", "[", "uvec", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ishift", "=", " ", 
       RowBox[{"i", "+", "1"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"degree", "+", "1", " ", "+", " ", "ishift"}], ">", " ", 
        "knotlength"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<illegal degree\>\"", ",", " ", 
          RowBox[{"ishift", "+", "1"}], ",", "\"\<>\>\"", ",", " ", 
          RowBox[{"knotlength", " ", "-", " ", "degree"}]}], "]"}], ";", 
        RowBox[{"Throw", "[", "illegalDegree", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"BSDivZero", "[", 
        RowBox[{
         RowBox[{"u", "-", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", "ishift", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree"}], "]"}], "]"}], "-", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", "ishift", "]"}], "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"BSBF", "[", 
        RowBox[{"i", ",", 
         RowBox[{"degree", "-", "1"}], ",", "uvec", ",", "u"}], "]"}]}], 
      "\[IndentingNewLine]", "+", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"BSDivZero", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree", " ", "+", "1"}], " ", "]"}], 
           "]"}], "-", "u"}], ",", 
         RowBox[{
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "degree", "+", "1"}], "]"}], "]"}], "-", 
          " ", 
          RowBox[{"uvec", "[", 
           RowBox[{"[", 
            RowBox[{"ishift", "+", "1"}], "]"}], "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", 
       RowBox[{"BSBF", "[", 
        RowBox[{
         RowBox[{"i", "+", " ", "1"}], ",", 
         RowBox[{"degree", "-", "1"}], ",", "uvec", ",", "u"}], "]"}]}]}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell["\<\
Take arbitrary knots and points, wrap on circle, return (number_points + \
degree) wrapped points and (numpoints + 2 degree + 1) \"periodic\" knots.\
\>", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Wrap", "[", 
   RowBox[{"knots_", ",", " ", "points_", ",", " ", "degree_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"numknots", "=", 
       RowBox[{"Length", "[", "knots", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"numpoints", " ", "=", " ", 
       RowBox[{"Length", "[", "points", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"knotintervals", "=", " ", 
       RowBox[{"Differences", "[", "knots", "]"}]}], ",", 
      "\[IndentingNewLine]", "closedknots", ",", "\[IndentingNewLine]", 
      "closedpoints"}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"closedknots", "[", "1", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"Last", "[", "knots", "]"}], " ", "+", " ", 
       RowBox[{"First", "[", "knotintervals", "]"}]}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "these", " ", "are", " ", "the", " ", "additional", " ", "knots"}], 
       ",", " ", 
       RowBox[{
       "to", " ", "be", " ", "joined", " ", "to", " ", "the", " ", 
        "original"}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"closedknots", "[", "n_", "]"}], " ", ":=", 
      RowBox[{
       RowBox[{"closedknots", "[", 
        RowBox[{"n", "-", "1"}], "]"}], " ", "+", " ", 
       RowBox[{"knotintervals", "[", 
        RowBox[{"[", 
         RowBox[{"Mod", "[", 
          RowBox[{"n", ",", 
           RowBox[{"(", 
            RowBox[{"numknots", "-", "1"}], ")"}], ",", "1"}], "]"}], "]"}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"closedpoints", " ", "=", " ", 
      RowBox[{
       RowBox[{"NestWhile", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{"#", ",", "#"}], "]"}], "&"}], ",", "points", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], " ", "\[LessEqual]", " ", 
            RowBox[{"numpoints", "+", "degree"}]}], ")"}], "&"}]}], "]"}], 
       "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", 
         RowBox[{"degree", "+", "numpoints"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"closedpoints", ",", 
       RowBox[{"Join", "[", 
        RowBox[{"knots", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"closedknots", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{
              RowBox[{"2", " ", "degree"}], "+", "1"}]}], "}"}]}], "]"}]}], 
        "]"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BSplinePeriodic", "[", 
    RowBox[{
    "controlpoints_", ",", " ", "knots_", ",", " ", "degree_", ",", "u_"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"closedpoints", ",", "\[IndentingNewLine]", "closedknots"}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"closedpoints", ",", "closedknots"}], "}"}], "=", " ", 
       RowBox[{"Wrap", "[", 
        RowBox[{"knots", ",", "controlpoints", ",", "degree"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"BSBF", "[", 
          RowBox[{"i", ",", "degree", ",", "closedknots", ",", "u"}], "]"}], 
         " ", 
         RowBox[{"closedpoints", "[", 
          RowBox[{"[", 
           RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{
           RowBox[{"Length", "[", "closedpoints", "]"}], "-", "1"}]}], 
         "}"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"uniformKnots", "[", "numsides_", "]"}], " ", ":=", " ", 
   RowBox[{"Range", "[", 
    RowBox[{"numsides", "+", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.423837938082451*^9, 3.423837965861113*^9}}],

Cell[CellGroupData[{

Cell["\<\
add up the sides along the perimeter of a polygon given ITs vertex \
coordinates.\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polygonSides", "[", "iverts_", "]"}], ":=", " ", 
  RowBox[{"Norm", "/@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"iverts", "[", 
       RowBox[{"[", 
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"i", "+", "1"}], ",", 
          RowBox[{"Length", "[", "iverts", "]"}], ",", "1"}], "]"}], "]"}], 
       "]"}], " ", "-", " ", 
      RowBox[{"iverts", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "iverts", "]"}]}], "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"polygonSides", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"polygonSides", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Importing and collating data", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rawData", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\</Users/ccarter/People/Neri/Chair/Beast_FineCount_UV_20.csv\>\"", ",",
      " ", "\"\<CSV\>\""}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"rawData", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", 
    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4239948067962723`*^9, 3.4239948092330227`*^9}, {
  3.423994970019652*^9, 3.423994971402948*^9}, {3.42399507672971*^9, 
  3.423995078153328*^9}}],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"rawData", ",", "16"}], "]"}]], "Input"],

Cell["Note: check data from file, format may change, wise to check", \
"Subsubsection"],

Cell[CellGroupData[{

Cell["XYZ", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvXYZ", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", " ", 
          RowBox[{"1", " ", ";;", " ", "2"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", " ", 
          RowBox[{"3", " ", ";;", " ", "5"}]}], "]"}], "]"}]}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"uvXYZ", " ", "//", " ", "Short"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataX", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "1"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Length", "[", "dataX", "]"}], "\n", 
 RowBox[{"dataX", " ", "//", " ", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataY", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "2"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";", " ", 
  RowBox[{"dataZ", " ", "=", " ", 
   RowBox[{"Sort", "[", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "[", "#", "]"}], ",", " ", 
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", " ", "3"}], "]"}], "]"}]}], "}"}], " ", "&"}], 
      ",", " ", "uvXYZ"}], "]"}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curvature", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanCurvatureValuesRaw", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"rawData", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"meanCurvatureValuesRaw", "//", "Short"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mincuve", ",", "maxcurve"}], "}"}], "=", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max"}], "}"}], "[", "meanCurvatureValuesRaw", "]"}],
    "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normals", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uvnormals", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"6", ";;", "8"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"uvnormals", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"nxdata", ",", "nydata", ",", "nzdata"}], "}"}], "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sort", "[", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"First", "[", "#", "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "i"}], "]"}], "]"}]}], "}"}], "&"}], ",", 
        "uvnormals"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Visualization and Rescaling", "Section"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"meanCurvatureValuesRaw", ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Changed to Absolute Curvature", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Values of curvature limits may change", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"meanCurvatureValuesAbs", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"Abs", ",", "meanCurvatureValuesRaw"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"meanCurvatureValuesAbs", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"mincurvatureabs", ",", "maxcurvatureabs"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Min", "[", "meanCurvatureValuesAbs", "]"}], ",", 
    RowBox[{"Max", "[", "meanCurvatureValuesAbs", "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"meanCurvatureValuesAbs", ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"],

Cell["{{{u, v}, H}, ..}", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataCurvature", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rawData", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", 
          RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"meanCurvatureValuesAbs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/", "maxcurvatureabs"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "rawData", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dataCurvature", "//", "Short"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"Last", "/@", "dataCurvature"}], ",", 
   RowBox[{"HistogramCategories", "\[Rule]", " ", "50"}]}], "]"}]], "Input"],

Cell["{{{u, v}, H}, ..}", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal angle maps", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", "Pi"}], ")"}], 
     RowBox[{"Abs", "[", 
      RowBox[{"ArcSin", "[", "z", "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attempts to mirror", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xmin", ",", "xmax"}], "}"}], "=", " ", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max"}], "}"}], "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "&"}], ",", "rawData"}], "]"}], "]"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"ymin", ",", "ymax"}], "}"}], "=", " ", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max"}], "}"}], "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "&"}], ",", "rawData"}], "]"}], "]"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"zmin", ",", "zmax"}], "}"}], "=", " ", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max"}], "}"}], "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "&"}], ",", "rawData"}], "]"}], "]"}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataX", "=", " ", 
   RowBox[{"(*", 
    RowBox[{"will", " ", "need", " ", "to", " ", "fix"}], "*)"}], 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataX", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataX", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataX", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataX", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataY", "=", 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataY", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataY", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataY", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataY", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"mdataZ", "=", 
   RowBox[{"Sort", "@", 
    RowBox[{"Join", "[", 
     RowBox[{"dataZ", ",", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "10"}], ",", "0"}], "}"}], "+", 
               RowBox[{"dataZ", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ",", 
              RowBox[{"dataZ", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "dataZ", "]"}]}], "}"}]}], "]"}]}], 
         "]"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[NotEqual]", " ", "5"}],
           ")"}], "&"}]}], "]"}]}], "]"}]}]}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interpolations", "Section"],

Cell[CellGroupData[{

Cell["Look at interpolation order as improvement in future", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"fx", ",", "fy", ",", "fz"}], "}"}], "=", " ", 
  RowBox[{"Interpolation", "/@", 
   RowBox[{"{", 
    RowBox[{"dataX", ",", "dataY", ",", "dataZ"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ul", ",", "uh"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"vl", ",", "vh"}], "}"}]}], "}"}], "=", 
  RowBox[{"fx", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"llx", ",", "lly"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"lrx", ",", "lry"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"urx", ",", "ury"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ulx", ",", "uly"}], "}"}]}], "}"}], "=", 
   RowBox[{"bounds", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ul", ",", "vl"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"uh", ",", "vl"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"uh", ",", "vh"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"ul", ",", "vh"}], "}"}]}], "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mx", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
       "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "uh"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "*", "uh"}], "-", "u"}], ",", "v"}], "]"}], ",", 
       RowBox[{"uh", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
        RowBox[{"2", "*", "uh"}]}]}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"my", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
       "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "uh"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"2", "ymin"}], "-", 
        RowBox[{"fy", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", "*", "uh"}], "-", "u"}], ",", "v"}], "]"}]}], ",", 
       RowBox[{"uh", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
        RowBox[{"2", "*", "uh"}]}]}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mz", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
       "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "uh"}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"2", "*", "uh"}], "-", "u"}], ",", "v"}], "]"}], ",", 
       RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
        RowBox[{"2", "*", "uh"}]}]}], "}"}]}], "}"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"my", "[", 
  RowBox[{"24", ",", "3"}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dfxdu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfxdv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fx", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfydu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfydv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fy", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfzdu", " ", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}], ";", " ", 
  RowBox[{"dfzdv", "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], ";", 
  "\[IndentingNewLine]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"dfxdu", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"llx", "+", "lrx"}], ")"}], "/", "2"}]}], ",", 
    RowBox[{"v", "\[Rule]", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{"lly", "+", "uly"}], ")"}], "/", "2"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"unsymarea", "[", 
   RowBox[{"uval_", ",", "vval_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"Norm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dfxdu", ",", "dfydu", ",", "dfzdu"}], "}"}], "\[Cross]", 
     RowBox[{"{", 
      RowBox[{"dfxdv", ",", "dfydv", ",", "dfzdv"}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", " ", "uval"}], ",", " ", 
     RowBox[{"v", "\[Rule]", " ", "vval"}]}], 
    "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"area", "[", 
   RowBox[{"uval_", ",", "vval_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"unsymarea", "[", 
      RowBox[{"uval", ",", "vval"}], "]"}], " ", "+", " ", 
     RowBox[{"unsymarea", "[", 
      RowBox[{"uval", ",", 
       RowBox[{"20.0", "-", "vval"}]}], "]"}]}], ")"}], "/", 
   "2.0"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"area", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ul", "+", "uh"}], ")"}], "/", "2"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vl", "+", "vh"}], ")"}], "/", "2"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"mx", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"(*", 
    RowBox[{"will", " ", "need", " ", "to", " ", "fix"}], "*)"}], 
   RowBox[{
    RowBox[{
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fx", "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
          "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}], 
         "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fx", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}], ",", 
          RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
           RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}], 
     "\[IndentingNewLine]", 
     RowBox[{"my", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}]}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"Piecewise", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"fy", "[", 
            RowBox[{"u", ",", "v"}], "]"}], ",", 
           RowBox[{
           "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}],
           "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"2", 
             StyleBox["*", "Code"], "50.4042"}], " ", "-", 
            RowBox[{"fy", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}]}], 
           ",", 
           RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
            RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}], 
      "\[IndentingNewLine]", 
      RowBox[{"mz", "[", 
       RowBox[{"u_", ",", "v_"}], "]"}]}], ":=", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fz", "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
          "0", "\[LessEqual]", " ", "u", " ", "\[LessEqual]", " ", "8.5"}]}], 
         "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"fz", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"2", "*", "8.5"}], "-", "u"}], ",", "v"}], "]"}], ",", 
          RowBox[{"8.5", " ", "<", " ", "u", " ", "\[LessEqual]", " ", 
           RowBox[{"2", "*", "8.5"}]}]}], "}"}]}], "}"}], "]"}]}]}]}], 
  "\[IndentingNewLine]", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"mfx", ",", "mfy", ",", "mfz"}], "}"}], "=", " ", 
   RowBox[{"Interpolation", "/@", 
    RowBox[{"{", 
     RowBox[{"mdataX", ",", "mdataY", ",", "mdataZ"}], "}"}]}]}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"rawcurvinterpolation", "=", " ", 
  RowBox[{"Interpolation", "[", "dataCurvature", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Clear", "[", "Curvature", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Curvature", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"rawcurvinterpolation", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "+", 
     RowBox[{"rawcurvinterpolation", "[", 
      RowBox[{"u", ",", 
       RowBox[{"20.", "-", "v"}]}], "]"}]}], ")"}], "/", "2.0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}], "=", " ", 
  RowBox[{"Interpolation", "/@", 
   RowBox[{"{", 
    RowBox[{"nxdata", ",", "nydata", ",", "nzdata"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"SaveNames", "<>", "\"\<interpolations.mx\>\""}], ",", 
    RowBox[{"{", 
     RowBox[{
     "fx", ",", "fy", ",", "fz", ",", "dfxdu", ",", "dfydu", ",", "dfzdu", 
      ",", "dfxdv", ",", "dfydv", ",", "dfzdv", ",", "area", ",", "Curvature",
       ",", "nx", ",", "ny", ",", "nz"}], "}"}]}], "]"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D representations of interpolations", "Section"],

Cell[CellGroupData[{

Cell["surface with uv mesh", "Subsection"],

Cell[BoxData[
 RowBox[{"pall", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "ul", ",", "uh"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "vl", ",", "vh"}], "}"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"FaceForm", "[", 
        RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
               RowBox[{"#1", " ", 
                RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], "^",
            "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"BoxRatios", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"154.952", ",", "39.2074", ",", "56.7391"}], "}"}]}], ","}], 
     "*)"}], 
    RowBox[{"ImageSize", "\[Rule]", " ", "Full"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psmallu", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "ul", ",", 
       RowBox[{"0.2", "uh"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "vl", ",", "vh"}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"FaceForm", "[", 
         RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
     RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
                RowBox[{"#1", " ", 
                 RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], 
            "^", "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
     RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"BoxRatios", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"154.952", ",", "39.2074", ",", "56.7391"}], "}"}]}], ","}], 
      "*)"}], 
     RowBox[{"ImageSize", "\[Rule]", " ", "Small"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plargeu", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"0.8", " ", "uh"}], ",", "uh"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "vl", ",", "vh"}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"FaceForm", "[", 
         RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
     RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
                RowBox[{"#1", " ", 
                 RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], 
            "^", "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
     RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"BoxRatios", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"154.952", ",", "39.2074", ",", "56.7391"}], "}"}]}], ","}], 
      "*)"}], 
     RowBox[{"ImageSize", "\[Rule]", " ", "Small"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psmallv", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "ul", ",", "uh"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "vl", ",", 
       RowBox[{"0.2", "vh"}]}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"FaceForm", "[", 
         RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
     RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
                RowBox[{"#1", " ", 
                 RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], 
            "^", "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
     RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"BoxRatios", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"154.952", ",", "39.2074", ",", "56.7391"}], "}"}]}], ","}], 
      "*)"}], 
     RowBox[{"ImageSize", "\[Rule]", " ", "Small"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plargev", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "ul", ",", "uh"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"0.8", "vh"}], ",", "vh"}], "}"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"FaceForm", "[", 
         RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
     RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
                RowBox[{"#1", " ", 
                 RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], 
            "^", "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
     RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"BoxRatios", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"154.952", ",", "39.2074", ",", "56.7391"}], "}"}]}], ","}], 
      "*)"}], 
     RowBox[{"ImageSize", "\[Rule]", " ", "Small"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"psmallu", ",", "plargeu", ",", "psmallv", ",", "plargev"}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Full"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "llx", ",", "lrx"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "lly", ",", "uly"}], "}"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"FaceForm", "[", 
        RowBox[{"Orange", ",", "Yellow"}], "]"}]}], ","}], "*)"}], 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#3", " ", "#2"}], " ", "-", " ", 
               RowBox[{"#1", " ", 
                RowBox[{"#4", "/", "8"}]}]}], ")"}], "/", "350"}], "]"}], "^",
            "2"}], "<", ".5"}], "  ", "&"}], ")"}]}], ","}], "*)"}], 
    RowBox[{"MeshShading", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"RGBColor", "@@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.1", ",", "0.2", ",", "1"}], "}"}], 
            RowBox[{"RandomReal", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", "3"}], "]"}]}], ")"}]}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Glow", "[", 
          RowBox[{"RGBColor", "@@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.5", ",", "1"}], "}"}], 
             RowBox[{"RandomReal", "[", 
              RowBox[{
               RowBox[{"{", "}"}], ",", "3"}], "]"}]}], ")"}]}], "]"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", "Automatic"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", " ", "Full"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/testHalf_mod.dxf\>\"", ",", "p", 
    ",", "\"\<DXF\>\""}], "]"}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["curvature", "Subsection"],

Cell[BoxData[
 RowBox[{"pH", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "llx", ",", "lrx"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "lly", ",", "uly"}], "}"}], ",", 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z", ",", "u", ",", "v"}], "}"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.75", 
         RowBox[{"Curvature", "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", " ", "Top"}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["angle from vertical", "Subsection"],

Cell[BoxData[
 RowBox[{"pNorm", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fx", "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", ",", " ", 
      RowBox[{"fy", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"fz", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "llx", ",", "lrx"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "lly", ",", "uly"}], "}"}], ",", 
    RowBox[{"Mesh", "\[Rule]", " ", "True"}], ",", 
    RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z", ",", "u", ",", "v"}], "}"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{"0.75", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "/", "Pi"}], ")"}], 
            RowBox[{"Abs", "[", 
             RowBox[{"ArcSin", "[", 
              RowBox[{"nz", "[", 
               RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]}]}], ")"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"fX", ",", "fY", ",", "fZ"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Infinity"}], "}"}]}]}], "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Voronoi cells", "Section"],

Cell[CellGroupData[{

Cell["Uniform Voronoi", "Subsection"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2D", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"RandomReal", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"bounds", "[", 
           RowBox[{"[", 
            RowBox[{"4", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", "24", "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Shallow", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6"}], "}"}]}], "]"}], "&"}], ")"}], "[", 
  RowBox[{"delval", "=", 
   RowBox[{"DelaunayTriangulation", "[", "data2D", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"vorvert", ",", "vorval"}], "}"}], "=", 
   RowBox[{"VoronoiDiagram", "[", "data2D", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"diagvert1", ",", "diagval1"}], "}"}], "=", 
    RowBox[{"BoundedDiagram", "[", 
     RowBox[{"bounds", ",", "data2D"}], "]"}]}], ";"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"diagvert1", "//", "Short"}], "\[IndentingNewLine]", 
 RowBox[{"diagval1", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{"DiagramPlot", "[", 
  RowBox[{"data2D", ",", "diagvert1", ",", "diagval1"}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Macroscale Voronoi for buffers", "Subsection"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"u", ",", "vh"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fy", "[", 
    RowBox[{"u", ",", "vh"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fx", "[", 
    RowBox[{"u", ",", "vh"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"du", "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{"Norm", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"z", ",", "v"}], "]"}], ",", "z"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fy", "[", 
        RowBox[{"z", ",", "v"}], "]"}], ",", "z"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"z", ",", "v"}], "]"}], ",", "z"}], "]"}]}], "}"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dv", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"Norm", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fx", "[", 
        RowBox[{"u", ",", "z"}], "]"}], ",", "z"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fy", "[", 
        RowBox[{"u", ",", "z"}], "]"}], ",", "z"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"fz", "[", 
        RowBox[{"u", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "}"}], 
   "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ULength", "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"du", "[", "v", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "20"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VLength", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"dv", "[", "u", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "6"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pv", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"VLength", "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"VLmin", ",", "VLmax", ",", "VLMean"}], "}"}], " ", "=", " ", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max", ",", "Mean"}], "}"}], "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"VLength", "[", "u", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "20", ",", ".1"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"fitU", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", 
        RowBox[{"VLength", "[", "u", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "20", ",", ".1"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "U"}], "}"}], ",", "U"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"fitU", "/.", 
  RowBox[{"U", "\[Rule]", " ", "20"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"fitU", ",", 
     RowBox[{"{", 
      RowBox[{"U", ",", "0", ",", "20"}], "}"}]}], "]"}], ",", "pv"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pu", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"ULength", "[", "v", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"VLmin", ",", "VLmax", ",", "VLMean"}], "}"}], " ", "=", " ", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Max", ",", "Mean"}], "}"}], "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ULength", "[", "v", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "0", ",", "10", ",", ".1"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"fitV", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"v", ",", 
        RowBox[{"ULength", "[", "v", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "0", ",", "10", ",", ".1"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "V"}], "}"}], ",", "V"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"fitV", "/.", 
  RowBox[{"V", "\[Rule]", " ", "10"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"fitV", ",", 
     RowBox[{"{", 
      RowBox[{"V", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", "pu", ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"p", ",", "q"}], "]"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"p", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"lvq0", " ", 
   RowBox[{"u", "/", "20"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Piecewise", "[", "\[IndentingNewLine]", 
   RowBox[{"{", "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"v", "/", "10"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "lu0"}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"lu20", "-", "lu0"}], ")"}], 
           RowBox[{"u", "/", "20"}]}]}], ")"}]}], ",", " ", 
       RowBox[{"v", "\[LessEqual]", " ", "10"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"v", "-", "10"}], ")"}], "/", "10"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"lu0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"lu20", "-", "lu0"}], ")"}], 
           RowBox[{"u", "/", "20"}]}]}], ")"}]}], ",", " ", 
       RowBox[{"v", " ", ">", " ", "10"}]}], "}"}]}], "\[IndentingNewLine]", 
    "}"}], "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", 
   RowBox[{"pp_", ",", "qq_"}], "]"}], " ", ":=", 
  FractionBox[
   RowBox[{"10", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"lu0", " ", "lvq0"}], "-", 
      RowBox[{"lu0", " ", "pp"}], "+", 
      RowBox[{"lu20", " ", "pp"}], "+", 
      RowBox[{"lvq0", " ", "qq"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"lu0", " ", "lvq0"}], "-", 
    RowBox[{"lu0", " ", "pp"}], "+", 
    RowBox[{"lu20", " ", "pp"}]}]]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"p_", ",", "q_"}], "]"}], " ", ":=", " ", 
  RowBox[{"20", 
   RowBox[{"p", "/", "lvq0"}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"lvq0", "=", 
  RowBox[{"fitV", "/.", 
   RowBox[{"V", "\[Rule]", " ", "10"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"lu0", "=", " ", 
  RowBox[{"fitU", "/.", 
   RowBox[{"U", "\[Rule]", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"lu20", "=", 
  RowBox[{"fitU", "/.", 
   RowBox[{"U", "\[Rule]", "20"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ps", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"u", ",", "0"}], "]"}], ",", 
         RowBox[{"p", "[", 
          RowBox[{"u", ",", "0"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"u", ",", "20"}], "]"}], ",", 
         RowBox[{"p", "[", 
          RowBox[{"u", ",", "20"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"0", ",", "v"}], "]"}], ",", 
         RowBox[{"p", "[", 
          RowBox[{"0", ",", "v"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"q", "[", 
          RowBox[{"20", ",", "v"}], "]"}], ",", 
         RowBox[{"p", "[", 
          RowBox[{"20", ",", "v"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", "20"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"pall", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"pt", ",", "ps", ",", 
    RowBox[{"Axes", "\[Rule]", " ", "False"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["Note bounds on (u,v)", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"RandomInQP", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pr", ",", "qr"}], "}"}], ",", 
     RowBox[{
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"qr", ",", "pr"}], "}"}], "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"lu0", "-", "lu20"}], ",", "lu0"}], "}"}], "]"}], ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "lvq0"}], "}"}], "]"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"!", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"0", " ", "<", " ", 
            RowBox[{"u", "[", 
             RowBox[{"pr", ",", "qr"}], "]"}], "<", " ", "20"}], " ", "&&", 
           " ", 
           RowBox[{"0", " ", "<", " ", 
            RowBox[{"v", "[", 
             RowBox[{"pr", ",", "qr"}], "]"}], " ", "<", " ", "20"}]}], 
          ")"}]}], ",", ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"qr", ",", "pr"}], "}"}], "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"lu0", "-", "lu20"}], ",", "lu0"}], "}"}], "]"}], ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "lvq0"}], "}"}], "]"}]}], "}"}]}]}], "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"area", "[", 
         RowBox[{
          RowBox[{"u", "[", 
           RowBox[{"pr", ",", "qr"}], "]"}], ",", 
          RowBox[{"v", "[", 
           RowBox[{"pr", ",", "qr"}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"qr", ",", "pr"}], "}"}]}], "}"}]}]}], "]"}]}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"sz", "=", "100"}], ";", "\[IndentingNewLine]", 
   RowBox[{"ranqp", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{"RandomInQP", ",", 
      RowBox[{"{", "sz", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"sz", "/", "500"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"QPRandomInUV", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pr", ",", "qr", ",", "ur", ",", "vr"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qr", ",", "pr"}], "}"}], "=", " ", 
      RowBox[{"Through", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"q", ",", "p"}], "}"}], "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ur", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "20"}], "}"}], "]"}]}], ",", 
          RowBox[{"vr", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "20"}], "}"}], "]"}]}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"area", "[", 
          RowBox[{"ur", ",", "vr"}], "]"}], ",", 
         RowBox[{"Curvature", "[", 
          RowBox[{"ur", ",", "vr"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"qr", ",", "pr"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{"sz", "=", "50000"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ick", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "ick", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "sz"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"qpranduv", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"QPRandomInUV", ",", 
     RowBox[{"{", 
      RowBox[{"ick", ",", "1", ",", "sz"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"qpranduv", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"ranqp", "//", "Short"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"ranqp", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "//", "Short"}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Last", "[", "#", "]"}], ",", 
         RowBox[{
          RowBox[{"First", "[", "#", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}], "&"}], ",", 
     "qpranduv"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Show", "[", 
   RowBox[{"pall", ",", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"ranqp", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"selectedrandqp", " ", "=", " ", 
    RowBox[{"RandomChoice", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{"First", ",", "ranqp"}], "]"}], "\[Rule]", " ", 
       RowBox[{"Map", "[", 
        RowBox[{"Last", ",", "ranqp"}], "]"}]}], ",", "1000"}], "]"}]}], 
   ";"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"100", 
         RowBox[{"Abs", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}]}]}], ")"}]}], "&"}], 
    ",", "qpranduv"}], "]"}], "//", "Max"}]], "Input"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"10", 
         RowBox[{"Abs", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}]}]}], ")"}]}], "&"}], 
    ",", "qpranduv"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"10", 
         RowBox[{"Abs", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}]}]}], ")"}]}], "&"}], 
    ",", "qpranduv"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"selectedQRrandUV", "=", " ", 
   RowBox[{"RandomChoice", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"10", 
             RowBox[{"Abs", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}], "]"}]}]}], ")"}]}], 
         "&"}], ",", "qpranduv"}], "]"}], "\[Rule]", " ", 
      RowBox[{"Map", "[", 
       RowBox[{"Last", ",", "qpranduv"}], "]"}]}], ",", "2000"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Length", "[", "selectedrandqp", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Length", "[", 
    RowBox[{"Union", "[", "selectedrandqp", "]"}], "]"}]}], "*)"}]], "Input"],

Cell[BoxData[{
 RowBox[{"Length", "[", "selectedQRrandUV", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", 
  RowBox[{"Union", "[", "selectedQRrandUV", "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedrandqp", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".2", ",", "3"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".2", ",", "3"}], "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedrandqp", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".1", ",", "5"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".1", ",", "5"}], "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedrandqp", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".1", ",", ".4"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".1", ",", ".4"}], "]"}]}], "}"}]}], "]"}], ";"}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Show", "[", 
   RowBox[{"pall", ",", 
    RowBox[{"ListPlot", "[", "selectedrandqp", "]"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "selectedQRrandUV", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"pall", ",", 
   RowBox[{"ListPlot", "[", "selectedQRrandUV", "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"trapbounds", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"0", ",", "0"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"0", ",", "20"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"0", ",", "20"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"20", ",", "20"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"20", ",", "20"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"20", ",", "0"}], "]"}], ",", 
      RowBox[{"p", "[", 
       RowBox[{"20", ",", "0"}], "]"}]}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedQRrandUV", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".2", ",", "3"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".2", ",", "3"}], "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedQRrandUV", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".1", ",", "5"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".1", ",", "5"}], "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"AppendTo", "[", 
    RowBox[{"selectedQRrandUV", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{".1", ",", ".4"}], "]"}], ",", 
       RowBox[{"p", "[", 
        RowBox[{".1", ",", ".4"}], "]"}]}], "}"}]}], "]"}], ";"}], 
  "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vorvertsCurvqp", ",", "vorvalsCurv"}], "}"}], "=", 
    RowBox[{"BoundedDiagram", "[", 
     RowBox[{"trapbounds", ",", "selectedQRrandUV"}], "]"}]}], ";"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DiagramPlot", "[", 
  RowBox[{
  "selectedQRrandUV", ",", "vorvertsCurvqp", ",", "vorvalsCurv", ",", 
   RowBox[{"LabelPoints", "\[Rule]", " ", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"vorvertsCurvqp", "//", "Short"}]], "Input"],

Cell[BoxData[
 RowBox[{"vorvalsCurv", "//", "Short"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vorvertsCurv", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Through", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}], "@@", 
        RowBox[{"Reverse", "[", "#", "]"}]}], "]"}], "&"}], ",", 
     "vorvertsCurvqp"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"vorvertsCurv", "//", "Short"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"SaveNames", "<>", "\"\<voronoi.mx\>\""}], ",", 
    RowBox[{"{", 
     RowBox[{"vorvertsCurv", ",", "vorvalsCurv", ",", "selectedQRrandUV"}], 
     "}"}]}], "]"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use nearest on higher scale poisson distribution to get voronoi generating \
function.\
\>", "Subsection",
 CellChangeTimes->{{3.4238435356172*^9, 3.423843570980907*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"seconddata2D", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"bounds", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"bounds", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"bounds", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"bounds", "[", 
            RowBox[{"[", 
             RowBox[{"4", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"{", "32", "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", "30", "*)"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"nf", "=", 
  RowBox[{"Nearest", "[", "seconddata2D", "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Precalculations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"materialChoices", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GrayLevel", "[", "0.8", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0.6", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0.2", "]"}], ",", 
     RowBox[{"GrayLevel", "[", "0", "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"materialIndices", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"Length", "[", "materialChoices", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"materialMembers", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", "materialChoices", "]"}], "}"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"colorOfMaterial", "[", "materialindex_", "]"}], " ", ":=", " ", 
   RowBox[{"materialChoices", "[", 
    RowBox[{"[", "materialindex", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[CellGroupData[{

Cell["Gradient choice", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LoopMaterial", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"matchoice", "[", 
   RowBox[{"i_", ",", "localnorm_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "angleweight", ",", "nz", ",", "weights", ",", "thecolor", ",", 
      "theindex"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"Print", "[", "localnorm", "]"}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nz", "=", " ", 
      RowBox[{"localnorm", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"weights", "=", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"Abs", "[", "nz", "]"}], "^", "2"}], " ", "+", " ", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "nz", "]"}], "^", "2"}], "-", "0.5"}], " ", 
           ")"}], "xtab"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"xtab", ",", "0", ",", "1", ",", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Length", "[", "materialChoices", "]"}], "-", "1"}], 
            ")"}]}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<nz \>\"", ",", "nz", ",", " ", "\"\<\\t wts\>\"", ",", 
         "weights"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"theindex", "=", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{"weights", "\[Rule]", " ", "materialIndices"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "theindex", "]"}], "]"}], ",", "i"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LoopMaterial", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "=", " ", 
      RowBox[{"materialChoices", "[", 
       RowBox[{"[", "theindex", "]"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{"Transpose", "[", 
  RowBox[{"{", 
   RowBox[{"vorvalsCurv", "[", 
    RowBox[{"[", 
     RowBox[{"123", ",", "2"}], "]"}], "]"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"vorvertsCurv", "[", 
  RowBox[{"[", "158", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{"vorvertsCurv", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"vorvalsCurv", "[", 
      RowBox[{"[", 
       RowBox[{"123", ",", "2"}], "]"}], "]"}], "}"}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopInPlaneCenter", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mean", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{"vorvertsCurv", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"vorvalsCurv", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", "2"}], "]"}], "]"}], "}"}], "]"}]}], "]"}], 
       "]"}], "&"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"loopInPlaneCenter", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"loopNormal", "=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Normalize", "[", 
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}], "@@", "#"}], "]"}], 
        "]"}], "&"}], ",", "loopInPlaneCenter"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"loopNormal", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"matchoice", "[", 
  RowBox[{"1", ",", 
   RowBox[{"loopNormal", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"materialMembers", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", "materialChoices", "]"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"matchoice", "[", 
     RowBox[{"i", ",", 
      RowBox[{"loopNormal", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "loopNormal", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"materialMembers", ",", "12"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"LoopMaterial", ",", "12"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Length", ",", "materialMembers"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{"Length", ",", "materialMembers"}], "]"}], ",", 
   RowBox[{"FrequencyData", "\[Rule]", " ", "True"}], ",", 
   RowBox[{"BarStyle", "\[Rule]", " ", "materialChoices"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getLoopVertices", "[", 
   RowBox[{"i_", ",", " ", "verts_", ",", "vors_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ivor", ",", "itemp"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ivor", "=", " ", 
      RowBox[{"vors", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"verts", "[", 
        RowBox[{"[", 
         RowBox[{"ivor", "[", 
          RowBox[{"[", "itemp", "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"itemp", ",", "1", ",", 
         RowBox[{"Length", "[", "ivor", "]"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"loopVertices", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"getLoopVertices", "[", 
        RowBox[{"i", ",", "vorvertsCurv", ",", "vorvalsCurv"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"loopVertices", "//", "Short"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Length", "[", "loopVertices", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"loopVertices", ",", "12"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"nf", "[", 
  RowBox[{
   RowBox[{"loopInPlaneCenter", "[", 
    RowBox[{"[", "12", "]"}], "]"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getBufferSize", "[", 
   RowBox[{"i_", ",", "nearestfunction_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"closest", ",", "secondclosest", ",", "frac"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"closest", ",", "secondclosest"}], "}"}], "=", 
      RowBox[{"nearestfunction", "[", 
       RowBox[{
        RowBox[{"loopInPlaneCenter", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "2"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"frac", "=", 
      RowBox[{
       RowBox[{"Norm", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"loopInPlaneCenter", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "-", "closest"}], ")"}], ".", 
         RowBox[{"(", 
          RowBox[{"secondclosest", "-", "closest"}], ")"}]}], "]"}], "/", 
       RowBox[{"Norm", "[", 
        RowBox[{"(", 
         RowBox[{"secondclosest", "-", "closest"}], ")"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"scaling", " ", "bsize", " ", "with", " ", 
        RowBox[{"frac", ":", " ", 
         RowBox[{"fatter", " ", "in", " ", "middle"}]}]}], ",", " ", 
       RowBox[{"parameters", " ", "somewhat", " ", "arbitrary"}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"0.2", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "10"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"frac", "-", "0.5"}], ")"}], "^", "2"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopBuffers", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getBufferSize", "[", 
      RowBox[{"i", ",", "nf"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"loopBuffers", "//", "Short"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Length", "[", "loopBuffers", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Length", "[", "vorvertsCurv", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{
       RowBox[{"Mean", "[", 
        RowBox[{"loopVertices", "[", 
         RowBox[{"[", "#", "]"}], "]"}], "]"}], ",", 
       RowBox[{"loopBuffers", "[", 
        RowBox[{"[", "#", "]"}], "]"}]}], "]"}], "&"}], ",", 
    RowBox[{"Range", "[", 
     RowBox[{"Length", "[", "loopBuffers", "]"}], "]"}]}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getShrunkVerts", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"bsize", ",", "meanpos"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"bsize", "=", 
      RowBox[{"loopBuffers", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"loopInPlaneCenter", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"meanpos", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "bsize"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{"#", "-", "meanpos"}], ")"}]}]}], ")"}], "&"}], ",", 
       RowBox[{"loopVertices", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopShrunkVerts", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getShrunkVerts", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"splineOrder", "=", "3"}], ";", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"getSplineFunction", "[", "i_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"knots", ",", "shrunkverts", ",", "meanpos", ",", "bsize"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bsize", "=", 
        RowBox[{"loopBuffers", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"meanpos", "=", " ", 
        RowBox[{"loopInPlaneCenter", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"shrunkverts", "=", 
        RowBox[{"loopShrunkVerts", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"knots", "=", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", 
          RowBox[{"loopVertices", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"BSplinePeriodic", "[", 
        RowBox[{"shrunkverts", ",", "knots", ",", "splineOrder", ",", "s"}], 
        "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random spline order", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopSplineOrder", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"RandomChoice", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "2", ",", "1"}], "}"}], "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", "4"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"loopSplineOrder", "=", 
    RowBox[{"Table", "[", " ", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"fill", " ", "and", " ", "replace"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getSplineOrder", "[", 
    RowBox[{"i_", ",", "localnorm_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nz", ",", "weights", ",", "theindex"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", "localnorm", "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nz", "=", " ", 
       RowBox[{"localnorm", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"weights", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", "nz", "]"}], "+", " ", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Abs", "[", "nz", "]"}], "-", "0.5"}], " ", ")"}], 
             "xtab"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"Abs", "[", "nz", "]"}]}], ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"xtab", ",", "0", ",", ".5", ",", ".5"}], "}"}]}], "]"}]}], 
      ";", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<nz \>\"", ",", "nz", ",", " ", "\"\<\\t wts\>\"", ",", 
          "weights"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"theindex", "=", 
       RowBox[{"RandomChoice", "[", 
        RowBox[{"weights", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", "nz", "]"}], ">", "0.8"}], ",", 
        RowBox[{"theindex", "=", "2"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"loopSplineOrder", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", " ", "theindex"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"getSplineOrder", "[", 
     RowBox[{"i", ",", 
      RowBox[{"loopNormal", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "loopNormal", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"loopSplineOrder", ",", "12"}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", "loopSplineOrder", "]"}], "//", "N"}]], "Input"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getSplineFunction", "[", "i_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"knots", ",", "shrunkverts", ",", "meanpos", ",", "bsize"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bsize", "=", 
        RowBox[{"loopBuffers", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"meanpos", "=", " ", 
        RowBox[{"loopInPlaneCenter", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"shrunkverts", "=", 
        RowBox[{"loopShrunkVerts", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"knots", "=", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", 
          RowBox[{"loopVertices", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"BSplinePeriodic", "[", 
        RowBox[{"shrunkverts", ",", "knots", ",", 
         RowBox[{"loopSplineOrder", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", "s"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loopSpline", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getSplineFunction", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{"loopVertices", "[", 
  RowBox[{"[", "12", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"loopShrunkVerts", "[", 
  RowBox[{"[", "12", "]"}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numSegments", "=", " ", "256"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getSplineVertsInPlane", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tp", ",", "tn", ",", "knots", ",", "iter", ",", "numsides", ",", 
      "splineOrd"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"numsides", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"loopVertices", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"knots", "=", 
      RowBox[{"Range", "[", "numsides", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"splineOrd", "=", 
      RowBox[{"loopSplineOrder", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"tp", ",", "tn"}], "}"}], "=", " ", 
      RowBox[{"Wrap", "[", 
       RowBox[{"knots", ",", 
        RowBox[{"loopShrunkVerts", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "splineOrd"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"loopSpline", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "/.", 
        RowBox[{"s", "\[Rule]", " ", "iter"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"iter", ",", 
         RowBox[{"tn", "[", 
          RowBox[{"[", 
           RowBox[{"splineOrd", "+", "1"}], "]"}], "]"}], ",", 
         RowBox[{"tn", "[", 
          RowBox[{"[", 
           RowBox[{"splineOrd", "+", "1", "+", "numsides"}], "]"}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"tn", "[", 
             RowBox[{"[", 
              RowBox[{"splineOrd", "+", "1"}], "]"}], "]"}], "-", 
            RowBox[{"tn", "[", 
             RowBox[{"[", 
              RowBox[{"splineOrd", "+", "1", "+", "numsides"}], "]"}], 
             "]"}]}], "]"}], "/", "numSegments"}]}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop2D", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop2D", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"splineVertsInPlane", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getSplineVertsInPlane", "[", "iloop2D", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iloop2D", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop3D", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop3D", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"loopSplineVertices3D", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Map", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"fx", ",", "fy", ",", "fz"}], "}"}], "@@", "#"}], "]"}], 
        "&"}], ",", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "iloop3D", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"iloop3D", ",", "1", ",", 
       RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"loopSplineVertices3D", ",", "36"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"SaveNames", "<>", "\"\<loopdata.mx\>\""}], ",", 
    RowBox[{"{", 
     RowBox[{
     "splineVertsInPlane", ",", "loopSplineVertices3D", ",", 
      "loopSplineOrder", ",", "materialMembers", ",", "loopVertices", ",", 
      "loopShrunkVerts"}], "}"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"loopSplineVerts3D", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"loopSplineVertices3D", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vorvalsCurve", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], "*)"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Projection of u-v plane Voronoi loops onto 3D interpolated surface\
\>", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeLoop3D", "[", "i_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"LoopMaterial", "[", 
     RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
    RowBox[{"Polygon", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"First", "[", 
         RowBox[{"loopSplineVertices3D", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "}"}]}], "]"}], "]"}]}], 
   "}"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D Graphics Examples", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{
   "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir"}], 
   "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"MakeLoop3D", "[", "12", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"MakeLoop3D", "[", "5", "]"}], ",", 
   RowBox[{"Lighting", "\[Rule]", " ", "\"\<Neutral\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424017831618177*^9, 3.424017863340287*^9}, {
   3.4240179085652647`*^9, 3.424017949388892*^9}, 3.424018164102714*^9, {
   3.4240915508954763`*^9, 3.424091563092188*^9}}],

Cell[BoxData[
 RowBox[{"g3d", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"MakeLoop3D", "[", "iloop", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"iloop", ",", "1", ",", 
        RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", " ", "Full"}]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmptop", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"g3d", ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "Infinity"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmptopplan", "==", 
   RowBox[{"Show", "[", 
    RowBox[{"g3d", ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", " ", "Top"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<allmaterials_top.eps\>\"", ",", "tmptop", ",", "\"\<EPS\>\""}],
   "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<allmaterials_top_plan.eps\>\"", ",", "tmptopplan", ",", 
   "\"\<EPS\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<allmaterials_top.svg\>\"", ",", "tmptop", ",", "\"\<SVG\>\""}],
   "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<allmaterials_top_plan.svg\>\"", ",", "tmptopplan", ",", 
   "\"\<SVG\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<allmaterials.dxf\>\"", ",", "tmptop", ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphicsmat", "[", "i_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"graphicsmat", "[", "i", "]"}], "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MakeLoop3D", "[", "#", "]"}], "&"}], ",", " ", 
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", " ", "Full"}], ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"graphicsmat", "[", "4", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Writing data out", "Section"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"WriteLoop3D", "[", "i_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "directory", "=", " ", 
        "\"\</Users/ccarter/People/Neri/Chair/Data/\>\""}], ",", "filename"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"filename", "=", " ", 
       RowBox[{"StringJoin", "[", 
        RowBox[{"directory", ",", "\"\<loop_\>\"", ",", 
         RowBox[{"ToString", "[", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"i", ",", "6", ",", 
            RowBox[{"NumberPadding", "\[Rule]", " ", 
             RowBox[{"{", 
              RowBox[{"\"\<0\>\"", ",", "\"\<\>\""}], "}"}]}]}], "]"}], "]"}],
          ",", "\"\<dxf\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Export", "[", 
       RowBox[{"filename", ",", 
        RowBox[{"Graphics3D", "[", 
         RowBox[{
          RowBox[{"MakeLoop3D", "[", "i", "]"}], ",", 
          RowBox[{"Lighting", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}],
          "]"}], ",", "\"\<DXF\>\""}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_1.dxf\>\"", ",", 
   RowBox[{"graphicsmat", "[", "1", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_2.dxf\>\"", ",", 
   RowBox[{"graphicsmat", "[", "2", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_3.dxf\>\"", ",", 
   RowBox[{"graphicsmat", "[", "3", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_4.dxf\>\"", ",", 
   RowBox[{"graphicsmat", "[", "4", "]"}], ",", "\"\<DXF\>\""}], 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bumps", "Section",
 CellChangeTimes->{{3.4238436661066*^9, 3.423843668589039*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pushout", "[", 
   RowBox[{"theverts_", ",", " ", "distance_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"nx_", ",", " ", "ny_", ",", " ", "nz_"}], "}"}]}], "]"}], ":=", 
  " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"theverts", "[", 
      RowBox[{"[", "i", "]"}], "]"}], " ", "+", " ", 
     RowBox[{"distance", "*", 
      RowBox[{"{", 
       RowBox[{"nx", ",", "ny", ",", "nz"}], "}"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "theverts", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["sharp", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpProfile", "[", 
   RowBox[{
   "verts3D_", ",", " ", "frac_", ",", " ", "meanposition_", ",", " ", 
    "locnorm_", ",", " ", "approxradius_"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"pushout", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"meanposition", " ", "+", " ", 
         RowBox[{"frac", 
          RowBox[{"(", 
           RowBox[{"#", "-", "meanposition"}], ")"}]}]}], ")"}], "&"}], ",", 
      "verts3D"}], "]"}], ",", 
    RowBox[{"(*", 
     RowBox[{"??", "?"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"frac", " ", "approxradius"}], " ", "-", " ", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}], ",", "\[IndentingNewLine]", 
    "locnorm"}], "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["soft", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpProfile", "[", 
   RowBox[{
   "verts3D_", ",", " ", "frac_", ",", " ", "meanposition_", ",", " ", 
    "locnorm_", ",", " ", "approxradius_"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"pushout", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"meanposition", " ", "+", " ", 
         RowBox[{"frac", 
          RowBox[{"(", 
           RowBox[{"#", "-", "meanposition"}], ")"}]}]}], ")"}], "&"}], ",", 
      "verts3D"}], "]"}], ",", 
    RowBox[{"(*", 
     RowBox[{"??", "?"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"frac", " ", "approxradius"}], " ", ")"}], "^", "4"}]}], 
         "]"}], "-", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", " ", "approxradius", " ", ")"}], "^", "4"}]}], 
         "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{
           RowBox[{"(", " ", "approxradius", " ", ")"}], "^", "4"}]}], 
         "]"}]}], ")"}]}]}], ",", "\[IndentingNewLine]", "locnorm"}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Need to add a final cone point for lofting.  Shape is still arbitrary\
\>", "Subsubsection",
 CellChangeTimes->{{3.423843704462714*^9, 3.423843723317133*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBump", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "output", ",", "meaninplane", ",", "meanpos", ",", "approxrad", ",", 
      "loopverts"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]",
     
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FaceForm", "[", "]"}], ",", 
        RowBox[{"EdgeForm", "[", 
         RowBox[{"LoopMaterial", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
        RowBox[{"MakeLoop3D", "[", "i", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"meaninplane", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"approxrad", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", "-", "meaninplane"}], ")"}], "&"}], ",", 
          RowBox[{"splineVertsInPlane", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Return", "[", "output", "]"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"output", ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Hue", "[", 
             RowBox[{".75", " ", "ifrac"}], "]"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Polygon", "[", 
            RowBox[{"bumpProfile", "[", 
             RowBox[{
              RowBox[{"loopSplineVertices3D", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "ifrac", ",", "meanpos", 
              ",", 
              RowBox[{"loopNormal", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
            "]"}]}], "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", 
        "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"ifrac", ",", 
         RowBox[{"{", 
          RowBox[{".9", ",", ".6", ",", ".3", ",", ".1"}], "}"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"AppendTo", "[", 
      RowBox[{"output", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", ".2", ",", "0"}], "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"meanpos", "-", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", "2", "]"}], " ", 
            RowBox[{"loopNormal", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}], "}"}]}], "]"}], ";",
      "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBump", "[", 
   RowBox[{"i_", ",", " ", "frac_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "output", ",", "meaninplane", ",", "meanpos", ",", "approxrad", ",", 
      "loopverts"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"meanpos", "=", " ", 
      RowBox[{"Mean", "[", 
       RowBox[{"loopSplineVertices3D", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"meaninplane", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{"splineVertsInPlane", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"approxrad", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", "-", "meaninplane"}], ")"}], "&"}], ",", 
          RowBox[{"splineVertsInPlane", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"frac", "\[Equal]", "1"}], " ", "||", " ", 
        RowBox[{"frac", "\[Equal]", "1.0"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", "]"}], ",", 
          RowBox[{"EdgeForm", "[", 
           RowBox[{"LoopMaterial", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
          RowBox[{"MakeLoop3D", "[", "i", "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"frac", "\[Equal]", "0"}], " ", "||", " ", 
        RowBox[{"frac", "\[Equal]", " ", "0.0"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{"1", ",", ".2", ",", "0"}], "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"Mean", "[", 
            RowBox[{"bumpProfile", "[", 
             RowBox[{
              RowBox[{"loopSplineVertices3D", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "0.025", ",", "meanpos", 
              ",", 
              RowBox[{"loopNormal", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
            "]"}], "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", "True", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"output", "=", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", "]"}], ",", 
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Hue", "[", 
            RowBox[{".75", " ", "frac"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Polygon", "[", 
           RowBox[{"bumpProfile", "[", 
            RowBox[{
             RowBox[{"loopSplineVertices3D", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "frac", ",", "meanpos", 
             ",", 
             RowBox[{"loopNormal", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "approxrad"}], "]"}], 
           "]"}]}], "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"MakeBump", "[", "23", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iloop2", "=", "0"}], ";", 
  RowBox[{"ProgressIndicator", "[", 
   RowBox[{
    RowBox[{"Dynamic", "[", "iloop2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424017831618177*^9, 3.424017863340287*^9}, {
   3.4240179085652647`*^9, 3.424017949388892*^9}, 3.424018164102714*^9, {
   3.4240915508954763`*^9, 3.424091563092188*^9}, {3.424093934183593*^9, 
   3.4240939382227077`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "g3dBumpSet", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g3dBumpSet", "[", "frac_", "]"}], ":=", 
   RowBox[{
    RowBox[{"g3dBumpSet", "[", "frac", "]"}], "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MakeBump", "[", 
        RowBox[{"iloop2", ",", "frac"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"iloop2", ",", "1", ",", 
         RowBox[{"Length", "[", "vorvalsCurv", "]"}]}], "}"}]}], "]"}], 
     "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"g3dBumpSet", "[", "1", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"g3dBumpSet", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".9", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".6", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", ".1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"g3dBumpSet", "[", "0.0", "]"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allBumpstop", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"g3dBumpSet", "[", "j", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", ".9", ",", ".6", ",", ".3", ",", ".1", ",", "0"}],
           "}"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", " ", "Top"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"allBumpstopplan", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"g3dBumpSet", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", ".9", ",", ".6", ",", ".3", ",", ".1", ",", "0"}], 
         "}"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"ViewPoint", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "Infinity"}], "}"}]}]}], "]"}]}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<allmaterials_allbumps_top.eps\>\"", ",", "allBumpstop", ",", 
    "\"\<EPS\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<allmaterials_allbumps_plan.eps\>\"", ",", "allBumpstopplan", ",", 
   "\"\<EPS\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<allmaterials_allbumps_top.svg\>\"", ",", "allBumpstop", ",", 
    "\"\<SVG\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<allmaterials_allbumps_plan.svg\>\"", ",", "allBumpstopplan", ",", 
   "\"\<SVG\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<allmaterials_allbumps.dxf\>\"", ",", "allBumpstop", ",", 
   "\"\<DXF\>\""}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ExpSet", "[", "frac_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<bumpset_\>\"", "<>", 
        RowBox[{"ToString", "[", "frac", "]"}], "<>", "\"\<.eps\>\""}], ",", 
       RowBox[{"g3dBumpSet", "[", "frac", "]"}], ",", "\"\<EPS\>\""}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<bumpset_\>\"", "<>", 
        RowBox[{"ToString", "[", "frac", "]"}], "<>", "\"\<.svg\>\""}], ",", 
       RowBox[{"g3dBumpSet", "[", "frac", "]"}], ",", "\"\<SVG\>\""}], 
      "]"}]}], "}"}]}], "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[{
 RowBox[{"ExpSet", "[", "1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".9", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".5", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".25", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", ".1", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ExpSet", "[", "0", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{
    "\"\</Users/ccarter/People/Neri/Chair/ChairTrails/\>\"", "<>", "Dir", 
     "<>", "\"\</bumps.dxf\>\""}], ",", "g3dBumps", ",", "\"\<DXF\>\""}], 
   "]"}], "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bumpssmat", "[", "i_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"bumpssmat", "[", "i", "]"}], "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MakeBump", "[", "#", "]"}], "&"}], ",", " ", 
       RowBox[{"materialMembers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", " ", "Full"}], ",", 
     RowBox[{"Lighting", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"\"\<Ambient\>\"", ",", " ", "White"}], "}"}], "}"}]}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "2", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"bumpssmat", "[", "4", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_1+bumps.dxf\>\"", ",", 
   RowBox[{"bumpssmat", "[", "1", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_2+bumps.dxf\>\"", ",", 
   RowBox[{"bumpssmat", "[", "2", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<material_3+bumps.dxf\>\"", ",", 
   RowBox[{"bumpssmat", "[", "3", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\</material_4+bumps.dxf\>\"", ",", 
   RowBox[{"bumpssmat", "[", "4", "]"}], ",", "\"\<DXF\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DateString", "[", "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1221, 842},
WindowMargins->{{Automatic, 85}, {Automatic, 0}},
Magnification->1.,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"3016-Carter.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 63, 0, 64, "Title"],
Cell[CellGroupData[{
Cell[678, 27, 33, 0, 34, "Section"],
Cell[714, 29, 58, 1, 37, "Input"],
Cell[775, 32, 471, 13, 83, "Input"],
Cell[1249, 47, 83, 2, 37, "Input"],
Cell[1335, 51, 76, 1, 37, "Input"],
Cell[1414, 54, 87, 1, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1538, 60, 35, 0, 34, "Section"],
Cell[1576, 62, 416, 13, 37, "Input"],
Cell[CellGroupData[{
Cell[2017, 79, 29, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[2071, 83, 113, 1, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2187, 86, 320, 8, 37, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2510, 96, 179, 4, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[2692, 102, 971, 26, 98, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3666, 130, 157, 3, 24, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[3826, 135, 2616, 69, 218, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6445, 206, 231, 4, 34, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[6679, 212, 2803, 73, 203, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[9485, 287, 1315, 34, 173, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[10815, 324, 257, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[11097, 334, 114, 3, 24, "Subsubsection"],
Cell[11214, 339, 618, 18, 37, "Input"],
Cell[11835, 359, 782, 28, 53, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12678, 394, 47, 0, 34, "Section"],
Cell[12728, 396, 233, 6, 37, "Input"],
Cell[12964, 404, 300, 7, 37, "Input"],
Cell[13267, 413, 88, 2, 37, "Input"],
Cell[13358, 417, 87, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[13470, 422, 25, 0, 26, "Subsection"],
Cell[13498, 424, 672, 20, 53, "Input"],
Cell[14173, 446, 524, 15, 68, "Input"],
Cell[14700, 463, 817, 25, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15554, 493, 31, 0, 34, "Subsection"],
Cell[15588, 495, 713, 21, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16338, 521, 29, 0, 34, "Subsection"],
Cell[16370, 523, 626, 19, 53, "Input"],
Cell[16999, 544, 605, 19, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17653, 569, 51, 0, 34, "Section"],
Cell[17707, 571, 160, 3, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17904, 579, 52, 0, 44, "Subsubtitle"],
Cell[CellGroupData[{
Cell[17981, 583, 62, 0, 24, "Subsubsection"],
Cell[18046, 585, 253, 6, 53, "Input"],
Cell[18302, 593, 277, 7, 37, "Input"],
Cell[18582, 602, 160, 3, 37, "Input"],
Cell[18745, 607, 33, 0, 26, "Text"],
Cell[18781, 609, 660, 19, 68, "Input"],
Cell[19444, 630, 179, 4, 37, "Input"],
Cell[19626, 636, 33, 0, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19696, 641, 42, 0, 24, "Subsubsection"],
Cell[19741, 643, 328, 11, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20106, 659, 37, 0, 34, "Section"],
Cell[20146, 661, 377, 13, 37, "Input"],
Cell[20526, 676, 377, 13, 37, "Input"],
Cell[20906, 691, 377, 13, 37, "Input"],
Cell[21286, 706, 1759, 50, 53, "Input"],
Cell[23048, 758, 1669, 48, 53, "Input"],
Cell[24720, 808, 1669, 48, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26426, 861, 33, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[26484, 865, 74, 0, 34, "Subsection"],
Cell[26561, 867, 221, 6, 37, "Input"],
Cell[26785, 875, 255, 9, 37, "Input"],
Cell[27043, 886, 697, 23, 37, "Input"],
Cell[27743, 911, 2112, 67, 68, "Input"],
Cell[29858, 980, 79, 2, 37, "Input"],
Cell[29940, 984, 1098, 36, 83, "Input"],
Cell[31041, 1022, 343, 11, 37, "Input"],
Cell[31387, 1035, 900, 27, 53, "Input"],
Cell[32290, 1064, 234, 8, 37, "Input"],
Cell[32527, 1074, 2582, 75, 98, "Input"],
Cell[35112, 1151, 260, 8, 37, "Input"],
Cell[35375, 1161, 125, 2, 37, "Input"],
Cell[35503, 1165, 66, 1, 37, "Input"],
Cell[35572, 1168, 380, 11, 37, "Input"],
Cell[35955, 1181, 224, 6, 37, "Input"],
Cell[36182, 1189, 393, 9, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36624, 1204, 55, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[36704, 1208, 42, 0, 34, "Subsection"],
Cell[36749, 1210, 1769, 49, 68, "Input"],
Cell[38521, 1261, 1815, 50, 68, "Input"],
Cell[40339, 1313, 1820, 50, 68, "Input"],
Cell[42162, 1365, 1815, 50, 68, "Input"],
Cell[43980, 1417, 1815, 50, 68, "Input"],
Cell[45798, 1469, 231, 6, 37, "Input"],
Cell[46032, 1477, 2511, 69, 83, "Input"],
Cell[48546, 1548, 193, 5, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48776, 1558, 31, 0, 34, "Subsection"],
Cell[48810, 1560, 1386, 35, 68, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50233, 1600, 41, 0, 34, "Subsection"],
Cell[50277, 1602, 1714, 45, 68, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52040, 1653, 32, 0, 34, "Section"],
Cell[CellGroupData[{
Cell[52097, 1657, 37, 0, 34, "Subsection"],
Cell[52137, 1659, 26, 0, 37, "Input"],
Cell[52166, 1661, 847, 26, 37, "Input"],
Cell[53016, 1689, 295, 9, 37, "Input"],
Cell[53314, 1700, 174, 5, 37, "Input"],
Cell[53491, 1707, 249, 7, 53, "Input"],
Cell[53743, 1716, 126, 2, 53, "Input"],
Cell[53872, 1720, 117, 2, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54026, 1727, 52, 0, 34, "Subsection"],
Cell[54081, 1729, 196, 6, 37, "Input"],
Cell[54280, 1737, 196, 6, 37, "Input"],
Cell[54479, 1745, 196, 6, 37, "Input"],
Cell[54678, 1753, 547, 18, 37, "Input"],
Cell[55228, 1773, 547, 18, 37, "Input"],
Cell[55778, 1793, 504, 15, 53, "Input"],
Cell[56285, 1810, 226, 7, 37, "Input"],
Cell[56514, 1819, 439, 13, 37, "Input"],
Cell[56956, 1834, 399, 12, 37, "Input"],
Cell[57358, 1848, 88, 2, 37, "Input"],
Cell[57449, 1852, 208, 7, 37, "Input"],
Cell[57660, 1861, 226, 7, 37, "Input"],
Cell[57889, 1870, 439, 13, 37, "Input"],
Cell[58331, 1885, 399, 12, 37, "Input"],
Cell[58733, 1899, 88, 2, 37, "Input"],
Cell[58824, 1903, 260, 7, 37, "Input"],
Cell[59087, 1912, 100, 3, 37, "Input"],
Cell[59190, 1917, 1370, 41, 128, "Input"],
Cell[60563, 1960, 473, 15, 59, "Input"],
Cell[61039, 1977, 160, 5, 37, "Input"],
Cell[61202, 1984, 342, 9, 68, "Input"],
Cell[61547, 1995, 632, 20, 37, "Input"],
Cell[62182, 2017, 632, 20, 37, "Input"],
Cell[62817, 2039, 162, 4, 37, "Input"],
Cell[CellGroupData[{
Cell[63004, 2047, 45, 0, 24, "Subsubsection"],
Cell[63052, 2049, 1972, 58, 83, "Input"],
Cell[65027, 2109, 314, 8, 68, "Input"],
Cell[65344, 2119, 1164, 35, 68, "Input"],
Cell[66511, 2156, 289, 8, 53, "Input"],
Cell[66803, 2166, 281, 8, 53, "Input"],
Cell[67087, 2176, 83, 2, 37, "Input"],
Cell[67173, 2180, 168, 6, 37, "Input"],
Cell[67344, 2188, 462, 14, 37, "Input"],
Cell[67809, 2204, 294, 8, 37, "Input"],
Cell[68106, 2214, 371, 11, 37, "Input"],
Cell[68480, 2227, 467, 16, 37, "Input"],
Cell[68950, 2245, 475, 16, 37, "Input"],
Cell[69428, 2263, 476, 16, 37, "Input"],
Cell[69907, 2281, 742, 23, 37, "Input"],
Cell[70652, 2306, 220, 5, 53, "Input"],
Cell[70875, 2313, 183, 3, 53, "Input"],
Cell[71061, 2318, 907, 29, 68, "Input"],
Cell[71971, 2349, 215, 5, 37, "Input"],
Cell[72189, 2356, 76, 1, 37, "Input"],
Cell[72268, 2359, 189, 4, 37, "Input"],
Cell[72460, 2365, 822, 27, 37, "Input"],
Cell[73285, 2394, 913, 29, 68, "Input"],
Cell[74201, 2425, 271, 8, 37, "Input"],
Cell[74475, 2435, 197, 4, 37, "Input"],
Cell[74675, 2441, 67, 1, 37, "Input"],
Cell[74745, 2444, 64, 1, 37, "Input"],
Cell[74812, 2447, 345, 11, 37, "Input"],
Cell[75160, 2460, 65, 1, 37, "Input"],
Cell[75228, 2463, 257, 7, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75534, 2476, 180, 4, 34, "Subsection"],
Cell[75717, 2482, 927, 28, 37, "Input"],
Cell[76647, 2512, 95, 2, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76791, 2520, 39, 0, 34, "Section"],
Cell[76833, 2522, 718, 21, 68, "Input"],
Cell[77554, 2545, 235, 6, 53, "Input"],
Cell[CellGroupData[{
Cell[77814, 2555, 37, 0, 34, "Subsection"],
Cell[77854, 2557, 2281, 64, 158, "Input"],
Cell[80138, 2623, 26, 0, 37, "Input"],
Cell[80167, 2625, 177, 5, 37, "Input"],
Cell[80347, 2632, 90, 2, 37, "Input"],
Cell[80440, 2636, 257, 8, 37, "Input"],
Cell[80700, 2646, 628, 18, 53, "Input"],
Cell[81331, 2666, 409, 13, 53, "Input"],
Cell[81743, 2681, 86, 2, 37, "Input"],
Cell[81832, 2685, 148, 4, 37, "Input"],
Cell[81983, 2691, 750, 22, 83, "Input"],
Cell[82736, 2715, 98, 2, 37, "Input"],
Cell[82837, 2719, 275, 6, 37, "Input"],
Cell[83115, 2727, 800, 22, 83, "Input"],
Cell[83918, 2751, 476, 13, 53, "Input"],
Cell[84397, 2766, 70, 1, 37, "Input"],
Cell[84470, 2769, 93, 2, 37, "Input"],
Cell[84566, 2773, 149, 4, 37, "Input"],
Cell[84718, 2779, 1651, 46, 113, "Input"],
Cell[86372, 2827, 392, 11, 53, "Input"],
Cell[86767, 2840, 69, 1, 37, "Input"],
Cell[86839, 2843, 70, 1, 37, "Input"],
Cell[86912, 2846, 466, 14, 37, "Input"],
Cell[87381, 2862, 951, 26, 98, "Input"],
Cell[88335, 2890, 302, 9, 37, "Input"],
Cell[88640, 2901, 1248, 29, 143, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89925, 2935, 41, 0, 34, "Subsection"],
Cell[89969, 2937, 434, 13, 37, "Input"],
Cell[90406, 2952, 2835, 81, 233, "Input"],
Cell[93244, 3035, 95, 2, 37, "Input"],
Cell[93342, 3039, 1305, 30, 173, "Input"],
Cell[94650, 3071, 300, 9, 37, "Input"],
Cell[94953, 3082, 26, 0, 37, "Input"],
Cell[94982, 3084, 89, 2, 37, "Input"],
Cell[95074, 3088, 92, 2, 37, "Input"],
Cell[95169, 3092, 2055, 54, 158, "Input"],
Cell[97227, 3148, 290, 9, 37, "Input"],
Cell[97520, 3159, 324, 9, 37, "Input"],
Cell[97847, 3170, 290, 9, 37, "Input"],
Cell[98140, 3181, 702, 20, 53, "Input"],
Cell[98845, 3203, 355, 9, 37, "Input"],
Cell[99203, 3214, 344, 10, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99596, 3230, 93, 2, 34, "Section"],
Cell[99692, 3234, 563, 16, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100292, 3255, 39, 0, 34, "Section"],
Cell[100334, 3257, 170, 5, 37, "Input"],
Cell[100507, 3264, 64, 1, 37, "Input"],
Cell[100574, 3267, 180, 4, 37, "Input"],
Cell[100757, 3273, 478, 12, 37, "Input"],
Cell[101238, 3287, 382, 10, 37, "Input"],
Cell[101623, 3299, 749, 21, 53, "Input"],
Cell[102375, 3322, 137, 3, 37, "Input"],
Cell[102515, 3327, 150, 4, 37, "Input"],
Cell[102668, 3333, 137, 3, 37, "Input"],
Cell[102808, 3338, 150, 4, 37, "Input"],
Cell[102961, 3344, 133, 3, 37, "Input"],
Cell[103097, 3349, 635, 18, 37, "Input"],
Cell[103735, 3369, 64, 1, 37, "Input"],
Cell[103802, 3372, 64, 1, 37, "Input"],
Cell[103869, 3375, 64, 1, 37, "Input"],
Cell[103936, 3378, 64, 1, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104037, 3384, 35, 0, 34, "Section"],
Cell[104075, 3386, 1279, 33, 83, "Input"],
Cell[105357, 3421, 165, 4, 37, "Input"],
Cell[105525, 3427, 165, 4, 37, "Input"],
Cell[105693, 3433, 165, 4, 37, "Input"],
Cell[105861, 3439, 165, 4, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106063, 3448, 88, 1, 34, "Section"],
Cell[106154, 3451, 591, 17, 37, "Input"],
Cell[CellGroupData[{
Cell[106770, 3472, 27, 0, 34, "Subsection"],
Cell[106800, 3474, 884, 24, 113, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107721, 3503, 26, 0, 34, "Subsection"],
Cell[107750, 3505, 1532, 47, 113, "Input"],
Cell[CellGroupData[{
Cell[109307, 3556, 168, 3, 24, "Subsubsection"],
Cell[109478, 3561, 3160, 79, 308, "Input"],
Cell[112641, 3642, 3461, 83, 353, "Input"],
Cell[116105, 3727, 99, 2, 37, "Input"],
Cell[116207, 3731, 532, 13, 37, "Input"],
Cell[116742, 3746, 67, 1, 37, "Input"],
Cell[116812, 3749, 482, 14, 37, "Input"],
Cell[117297, 3765, 63, 1, 37, "Input"],
Cell[117363, 3768, 391, 6, 113, "Input"],
Cell[117757, 3776, 965, 28, 53, "Input"],
Cell[118725, 3806, 829, 22, 98, "Input"],
Cell[119557, 3830, 695, 17, 68, "Input"],
Cell[120255, 3849, 366, 6, 113, "Input"],
Cell[120624, 3857, 258, 7, 37, "Input"],
Cell[120885, 3866, 629, 18, 37, "Input"],
Cell[121517, 3886, 62, 1, 37, "Input"],
Cell[121582, 3889, 62, 1, 37, "Input"],
Cell[121647, 3892, 62, 1, 37, "Input"],
Cell[121712, 3895, 62, 1, 37, "Input"],
Cell[121777, 3898, 166, 3, 37, "Input"],
Cell[121946, 3903, 166, 3, 37, "Input"],
Cell[122115, 3908, 166, 3, 37, "Input"],
Cell[122284, 3913, 167, 3, 37, "Input"],
Cell[122454, 3918, 58, 1, 37, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
